@@ -15,7 +15,6 @@
 
 #![deny(missing_docs)]
 #![deny(unsafe_code)]
-#![deny(fat_ptr_transmutes)]
 
 #![cfg_attr(feature = "nightly", feature(i128_type))]
 #![cfg_attr(feature = "bench",   feature(test))]
@@ -27,18 +26,19 @@ extern crate core;
 extern crate num_traits;
 
 
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 use core::ops::BitAnd;
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 use core::ops::BitOr;
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 use core::ops::Not;
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 use core::ops::Sub;
 
+#[cfg(all(feature = "generic-impls"))]
 use core::ops::Neg;
 
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 use num_traits::One;
 
 /// A `Mask` represents a choice which is not a boolean.
@@ -76,13 +76,13 @@ macro_rules! generate_integer_equal {
                 let mut x: $t = !(self ^ other);
                 let mut shift: $t = $maxshift;
 
-                /// e.g. for a u8, do:
-                ///
-                ///    x &= x >> 4;
-                ///    x &= x >> 2;
-                ///    x &= x >> 1;
-                ///
-                /// This is variable only in the max size of the integer.
+                // e.g. for a u8, do:
+                //
+                //    x &= x >> 4;
+                //    x &= x >> 2;
+                //    x &= x >> 1;
+                //
+                // This is variable only in the max size of the integer.
                 while shift >= 1 {
                     x &= x >> shift;
                     shift /= 2;
@@ -301,6 +301,7 @@ pub trait ConditionallyNegatable {
     fn conditional_negate(&mut self, choice: Mask);
 }
 
+#[cfg(feature = "generic-impls")]
 impl<T> ConditionallyNegatable for T
     where T: ConditionallyAssignable, for<'a> &'a T: Neg<Output = T>
 {
@@ -362,7 +363,7 @@ impl<T> ConditionallyNegatable for T
 /// find some other way to only implement it for types which we know work
 /// correctly.
 #[inline(always)]
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "generic-impls"))]
 pub fn conditional_select<T>(a: T, b: T, choice: T) -> T
     where T: PartialEq + PartialOrd + Copy +
              One + Sub<T, Output = T> + Not<Output = T> +
@@ -383,6 +384,9 @@ pub trait ConditionallySwappable {
     fn conditional_swap(&mut self, other: &mut Self, choice: Mask);
 }
 
+// Feature gated because the generic implementation is likely not as
+// fast as a custom impl for many types and in many use cases.
+#[cfg(feature = "generic-impls")]
 impl<T> ConditionallySwappable for T
     where T: ConditionallyAssignable + Copy
 {
@@ -480,7 +484,7 @@ pub fn byte_is_nonzero(b: u8) -> Mask {
 /// ```
 ///
 /// This function is commonly used in various cryptographic applications, such
-/// as [signature verification](https://github.com/isislovecruft/ed25519-dalek/blob/0.3.2/src/ed25519.rs#L280),
+/// as [signature verification](https://github.com/dalek-cryptography/ed25519-dalek/blob/0.3.2/src/ed25519.rs#L280),
 /// among many other applications.
 ///
 /// # Return
@@ -519,7 +523,7 @@ mod test {
     }
 
     #[test]
-    #[cfg(feature = "std")]
+    #[cfg(all(feature = "std", feature = "generic-impls"))]
     fn conditional_select_i32() {
         let a: i32 = 5;
         let b: i32 = 13;
@@ -529,7 +533,7 @@ mod test {
     }
 
     #[test]
-    #[cfg(feature = "std")]
+    #[cfg(all(feature = "std", feature = "generic-impls"))]
     fn conditional_select_i64() {
         let c: i64 = 2343249123;
         let d: i64 = 8723884895;
